package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallShopExpressCode;

/**
 * 快递编码Mapper接口
 * 
 * @author chang
 * @date 2021-11-25
 */
public interface MallShopExpressCodeMapper 
{
    /**
     * 查询快递编码
     * 
     * @param id 快递编码主键
     * @return 快递编码
     */
    public MallShopExpressCode selectMallShopExpressCodeById(Long id);

    /**
     * 查询快递编码列表
     * 
     * @param mallShopExpressCode 快递编码
     * @return 快递编码集合
     */
    public List<MallShopExpressCode> selectMallShopExpressCodeList(MallShopExpressCode mallShopExpressCode);

    /**
     * 新增快递编码
     * 
     * @param mallShopExpressCode 快递编码
     * @return 结果
     */
    public int insertMallShopExpressCode(MallShopExpressCode mallShopExpressCode);

    /**
     * 修改快递编码
     * 
     * @param mallShopExpressCode 快递编码
     * @return 结果
     */
    public int updateMallShopExpressCode(MallShopExpressCode mallShopExpressCode);

    /**
     * 删除快递编码
     * 
     * @param id 快递编码主键
     * @return 结果
     */
    public int deleteMallShopExpressCodeById(Long id);

    /**
     * 批量删除快递编码
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallShopExpressCodeByIds(Long[] ids);
}
